pub fn validate_strict_json_value(
value: &JsonValue,
path: &str,
) -> JsonCodecResult<()>Expand description
Shared strict JSON value validator for checkpoint and storage canonical bytes.
pub fn validate_strict_json_value(
value: &JsonValue,
path: &str,
) -> JsonCodecResult<()>Shared strict JSON value validator for checkpoint and storage canonical bytes.